@@ -377,42 +377,6 @@ public:
         ~ScriptScopeGuard() { --script_scope; }
     };
 
-    /**
-     * Changes the frequency for publishing scraped metrics to the target topic.
-     * Passing a zero-length interval has no effect.
-     * @param value Interval between two scrapes in seconds.
-     */
-    void SetMetricsExportInterval(double value);
-
-    /**
-     * Sets a new target topic for the metrics. Passing an empty string has no
-     * effect.
-     * @param value The new topic for publishing local metrics to.
-     */
-    void SetMetricsExportTopic(std::string value);
-
-    /**
-     * Sets the import topics for a node importing metrics.
-     *
-     * @param topics List of topics from which to import metrics.
-     */
-    void SetMetricsImportTopics(std::vector<std::string> topics);
-
-    /**
-     * Sets a new ID for the metrics exporter. Passing an empty string has no
-     * effect.
-     * @param value The new ID of the exporter in published metrics.
-     */
-    void SetMetricsExportEndpointName(std::string value);
-
-    /**
-     * Sets a prefix selection for the metrics exporter. An empty vector selects
-     * *all* metrics.
-     * @param filter List of selected metric prefixes or an empty vector for
-     *               selecting all metrics.
-     */
-    void SetMetricsExportPrefixes(std::vector<std::string> filter);
-
 private:
     // Process events used for Broker store backed zeek tables
     void ProcessStoreEvent(broker::data msg);
